==> camel-k-model-v1-5.3.0-sources.jar: annotations/io/fabric8/camelk/v1/SourceSpecFluent.java <==
package io.fabric8.camelk.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface SourceSpecFluent<A extends SourceSpecFluent<A>> extends Fluent<A> {


    public Boolean getCompression();
    public A withCompression(Boolean compression);
    public Boolean hasCompression();
    public A withNewCompression(String arg1);
    public A withNewCompression(boolean arg1);
    public String getContent();
    public A withContent(String content);
    public Boolean hasContent();
    public A withNewContent(StringBuilder arg1);
    public A withNewContent(int[] arg1,int arg2,int arg3);
    public A withNewContent(char[] arg1);
    public A withNewContent(StringBuffer arg1);
    public A withNewContent(byte[] arg1,int arg2);
    public A withNewContent(byte[] arg1);
    public A withNewContent(char[] arg1,int arg2,int arg3);
    public A withNewContent(byte[] arg1,int arg2,int arg3);
    public A withNewContent(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewContent(String arg1);
    public String getContentKey();
    public A withContentKey(String contentKey);
    public Boolean hasContentKey();
    public A withNewContentKey(StringBuilder arg1);
    public A withNewContentKey(int[] arg1,int arg2,int arg3);
    public A withNewContentKey(char[] arg1);
    public A withNewContentKey(StringBuffer arg1);
    public A withNewContentKey(byte[] arg1,int arg2);
    public A withNewContentKey(byte[] arg1);
    public A withNewContentKey(char[] arg1,int arg2,int arg3);
    public A withNewContentKey(byte[] arg1,int arg2,int arg3);
    public A withNewContentKey(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewContentKey(String arg1);
    public String getContentRef();
    public A withContentRef(String contentRef);
    public Boolean hasContentRef();
    public A withNewContentRef(StringBuilder arg1);
    public A withNewContentRef(int[] arg1,int arg2,int arg3);
    public A withNewContentRef(char[] arg1);
    public A withNewContentRef(StringBuffer arg1);
    public A withNewContentRef(byte[] arg1,int arg2);
    public A withNewContentRef(byte[] arg1);
    public A withNewContentRef(char[] arg1,int arg2,int arg3);
    public A withNewContentRef(byte[] arg1,int arg2,int arg3);
    public A withNewContentRef(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewContentRef(String arg1);
    public A addToInterceptors(int index,String item);
    public A setToInterceptors(int index,String item);
    public A addToInterceptors(String... items);
    public A addAllToInterceptors(Collection<String> items);
    public A removeFromInterceptors(String... items);
    public A removeAllFromInterceptors(Collection<String> items);
    public List<String> getInterceptors();
    public String getInterceptor(int index);
    public String getFirstInterceptor();
    public String getLastInterceptor();
    public String getMatchingInterceptor(Predicate<String> predicate);
    public Boolean hasMatchingInterceptor(Predicate<String> predicate);
    public A withInterceptors(List<String> interceptors);
    public A withInterceptors(String... interceptors);
    public Boolean hasInterceptors();
    public A addNewInterceptor(StringBuilder arg1);
    public A addNewInterceptor(int[] arg1,int arg2,int arg3);
    public A addNewInterceptor(char[] arg1);
    public A addNewInterceptor(StringBuffer arg1);
    public A addNewInterceptor(byte[] arg1,int arg2);
    public A addNewInterceptor(byte[] arg1);
    public A addNewInterceptor(char[] arg1,int arg2,int arg3);
    public A addNewInterceptor(byte[] arg1,int arg2,int arg3);
    public A addNewInterceptor(byte[] arg1,int arg2,int arg3,int arg4);
    public A addNewInterceptor(String arg1);
    public String getLanguage();
    public A withLanguage(String language);
    public Boolean hasLanguage();
    public A withNewLanguage(StringBuilder arg1);
    public A withNewLanguage(int[] arg1,int arg2,int arg3);
    public A withNewLanguage(char[] arg1);
    public A withNewLanguage(StringBuffer arg1);
    public A withNewLanguage(byte[] arg1,int arg2);
    public A withNewLanguage(byte[] arg1);
    public A withNewLanguage(char[] arg1,int arg2,int arg3);
    public A withNewLanguage(byte[] arg1,int arg2,int arg3);
    public A withNewLanguage(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewLanguage(String arg1);
    public String getLoader();
    public A withLoader(String loader);
    public Boolean hasLoader();
    public A withNewLoader(StringBuilder arg1);
    public A withNewLoader(int[] arg1,int arg2,int arg3);
    public A withNewLoader(char[] arg1);
    public A withNewLoader(StringBuffer arg1);
    public A withNewLoader(byte[] arg1,int arg2);
    public A withNewLoader(byte[] arg1);
    public A withNewLoader(char[] arg1,int arg2,int arg3);
    public A withNewLoader(byte[] arg1,int arg2,int arg3);
    public A withNewLoader(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewLoader(String arg1);
    public String getName();
    public A withName(String name);
    public Boolean hasName();
    public A withNewName(StringBuilder arg1);
    public A withNewName(int[] arg1,int arg2,int arg3);
    public A withNewName(char[] arg1);
    public A withNewName(StringBuffer arg1);
    public A withNewName(byte[] arg1,int arg2);
    public A withNewName(byte[] arg1);
    public A withNewName(char[] arg1,int arg2,int arg3);
    public A withNewName(byte[] arg1,int arg2,int arg3);
    public A withNewName(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewName(String arg1);
    public A addToPropertyNames(int index,String item);
    public A setToPropertyNames(int index,String item);
    public A addToPropertyNames(String... items);
    public A addAllToPropertyNames(Collection<String> items);
    public A removeFromPropertyNames(String... items);
    public A removeAllFromPropertyNames(Collection<String> items);
    public List<String> getPropertyNames();
    public String getPropertyName(int index);
    public String getFirstPropertyName();
    public String getLastPropertyName();
    public String getMatchingPropertyName(Predicate<String> predicate);
    public Boolean hasMatchingPropertyName(Predicate<String> predicate);
    public A withPropertyNames(List<String> propertyNames);
    public A withPropertyNames(String... propertyNames);
    public Boolean hasPropertyNames();
    public A addNewPropertyName(StringBuilder arg1);
    public A addNewPropertyName(int[] arg1,int arg2,int arg3);
    public A addNewPropertyName(char[] arg1);
    public A addNewPropertyName(StringBuffer arg1);
    public A addNewPropertyName(byte[] arg1,int arg2);
    public A addNewPropertyName(byte[] arg1);
    public A addNewPropertyName(char[] arg1,int arg2,int arg3);
    public A addNewPropertyName(byte[] arg1,int arg2,int arg3);
    public A addNewPropertyName(byte[] arg1,int arg2,int arg3,int arg4);
    public A addNewPropertyName(String arg1);
    public String getType();
    public A withType(String type);
    public Boolean hasType();
    public A withNewType(StringBuilder arg1);
    public A withNewType(int[] arg1,int arg2,int arg3);
    public A withNewType(char[] arg1);
    public A withNewType(StringBuffer arg1);
    public A withNewType(byte[] arg1,int arg2);
    public A withNewType(byte[] arg1);
    public A withNewType(char[] arg1,int arg2,int arg3);
    public A withNewType(byte[] arg1,int arg2,int arg3);
    public A withNewType(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewType(String arg1);
}

==> camel-k-model-v1-5.3.1-sources.jar: annotations/io/fabric8/camelk/v1/SourceSpecFluent.java <==
package io.fabric8.camelk.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface SourceSpecFluent<A extends SourceSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    public Boolean getCompression();
    public A withCompression(Boolean compression);
    public Boolean hasCompression();
    public A withNewCompression(String arg1);
    public A withNewCompression(boolean arg1);
    public String getContent();
    public A withContent(String content);
    public Boolean hasContent();
    public A withNewContent(StringBuilder arg1);
    public A withNewContent(int[] arg1,int arg2,int arg3);
    public A withNewContent(char[] arg1);
    public A withNewContent(StringBuffer arg1);
    public A withNewContent(byte[] arg1,int arg2);
    public A withNewContent(byte[] arg1);
    public A withNewContent(char[] arg1,int arg2,int arg3);
    public A withNewContent(byte[] arg1,int arg2,int arg3);
    public A withNewContent(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewContent(String arg1);
    public String getContentKey();
    public A withContentKey(String contentKey);
    public Boolean hasContentKey();
    public A withNewContentKey(StringBuilder arg1);
    public A withNewContentKey(int[] arg1,int arg2,int arg3);
    public A withNewContentKey(char[] arg1);
    public A withNewContentKey(StringBuffer arg1);
    public A withNewContentKey(byte[] arg1,int arg2);
    public A withNewContentKey(byte[] arg1);
    public A withNewContentKey(char[] arg1,int arg2,int arg3);
    public A withNewContentKey(byte[] arg1,int arg2,int arg3);
    public A withNewContentKey(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewContentKey(String arg1);
    public String getContentRef();
    public A withContentRef(String contentRef);
    public Boolean hasContentRef();
    public A withNewContentRef(StringBuilder arg1);
    public A withNewContentRef(int[] arg1,int arg2,int arg3);
    public A withNewContentRef(char[] arg1);
    public A withNewContentRef(StringBuffer arg1);
    public A withNewContentRef(byte[] arg1,int arg2);
    public A withNewContentRef(byte[] arg1);
    public A withNewContentRef(char[] arg1,int arg2,int arg3);
    public A withNewContentRef(byte[] arg1,int arg2,int arg3);
    public A withNewContentRef(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewContentRef(String arg1);
    public A addToInterceptors(int index,String item);
    public A setToInterceptors(int index,String item);
    public A addToInterceptors(String... items);
    public A addAllToInterceptors(Collection<String> items);
    public A removeFromInterceptors(String... items);
    public A removeAllFromInterceptors(Collection<String> items);
    public List<String> getInterceptors();
    public String getInterceptor(int index);
    public String getFirstInterceptor();
    public String getLastInterceptor();
    public String getMatchingInterceptor(Predicate<String> predicate);
    public Boolean hasMatchingInterceptor(Predicate<String> predicate);
    public A withInterceptors(List<String> interceptors);
    public A withInterceptors(String... interceptors);
    public Boolean hasInterceptors();
    public A addNewInterceptor(StringBuilder arg1);
    public A addNewInterceptor(int[] arg1,int arg2,int arg3);
    public A addNewInterceptor(char[] arg1);
    public A addNewInterceptor(StringBuffer arg1);
    public A addNewInterceptor(byte[] arg1,int arg2);
    public A addNewInterceptor(byte[] arg1);
    public A addNewInterceptor(char[] arg1,int arg2,int arg3);
    public A addNewInterceptor(byte[] arg1,int arg2,int arg3);
    public A addNewInterceptor(byte[] arg1,int arg2,int arg3,int arg4);
    public A addNewInterceptor(String arg1);
    public String getLanguage();
    public A withLanguage(String language);
    public Boolean hasLanguage();
    public A withNewLanguage(StringBuilder arg1);
    public A withNewLanguage(int[] arg1,int arg2,int arg3);
    public A withNewLanguage(char[] arg1);
    public A withNewLanguage(StringBuffer arg1);
    public A withNewLanguage(byte[] arg1,int arg2);
    public A withNewLanguage(byte[] arg1);
    public A withNewLanguage(char[] arg1,int arg2,int arg3);
    public A withNewLanguage(byte[] arg1,int arg2,int arg3);
    public A withNewLanguage(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewLanguage(String arg1);
    public String getLoader();
    public A withLoader(String loader);
    public Boolean hasLoader();
    public A withNewLoader(StringBuilder arg1);
    public A withNewLoader(int[] arg1,int arg2,int arg3);
    public A withNewLoader(char[] arg1);
    public A withNewLoader(StringBuffer arg1);
    public A withNewLoader(byte[] arg1,int arg2);
    public A withNewLoader(byte[] arg1);
    public A withNewLoader(char[] arg1,int arg2,int arg3);
    public A withNewLoader(byte[] arg1,int arg2,int arg3);
    public A withNewLoader(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewLoader(String arg1);
    public String getName();
    public A withName(String name);
    public Boolean hasName();
    public A withNewName(StringBuilder arg1);
    public A withNewName(int[] arg1,int arg2,int arg3);
    public A withNewName(char[] arg1);
    public A withNewName(StringBuffer arg1);
    public A withNewName(byte[] arg1,int arg2);
    public A withNewName(byte[] arg1);
    public A withNewName(char[] arg1,int arg2,int arg3);
    public A withNewName(byte[] arg1,int arg2,int arg3);
    public A withNewName(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewName(String arg1);
    public A addToPropertyNames(int index,String item);
    public A setToPropertyNames(int index,String item);
    public A addToPropertyNames(String... items);
    public A addAllToPropertyNames(Collection<String> items);
    public A removeFromPropertyNames(String... items);
    public A removeAllFromPropertyNames(Collection<String> items);
    public List<String> getPropertyNames();
    public String getPropertyName(int index);
    public String getFirstPropertyName();
    public String getLastPropertyName();
    public String getMatchingPropertyName(Predicate<String> predicate);
    public Boolean hasMatchingPropertyName(Predicate<String> predicate);
    public A withPropertyNames(List<String> propertyNames);
    public A withPropertyNames(String... propertyNames);
    public Boolean hasPropertyNames();
    public A addNewPropertyName(StringBuilder arg1);
    public A addNewPropertyName(int[] arg1,int arg2,int arg3);
    public A addNewPropertyName(char[] arg1);
    public A addNewPropertyName(StringBuffer arg1);
    public A addNewPropertyName(byte[] arg1,int arg2);
    public A addNewPropertyName(byte[] arg1);
    public A addNewPropertyName(char[] arg1,int arg2,int arg3);
    public A addNewPropertyName(byte[] arg1,int arg2,int arg3);
    public A addNewPropertyName(byte[] arg1,int arg2,int arg3,int arg4);
    public A addNewPropertyName(String arg1);
    public String getType();
    public A withType(String type);
    public Boolean hasType();
    public A withNewType(StringBuilder arg1);
    public A withNewType(int[] arg1,int arg2,int arg3);
    public A withNewType(char[] arg1);
    public A withNewType(StringBuffer arg1);
    public A withNewType(byte[] arg1,int arg2);
    public A withNewType(byte[] arg1);
    public A withNewType(char[] arg1,int arg2,int arg3);
    public A withNewType(byte[] arg1,int arg2,int arg3);
    public A withNewType(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewType(String arg1);
}
